##  What is the delta between the Meta Model v4 and the Meta Model v3?
The critical difference is the newly added Platform Fact Sheet type. In addition, some Fact Sheet types have been renamed, and we added subtypes for some Fact Sheet types. You can find all the changes in the table below.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27491b677a441014a1d2a979ad7eb5fa_LowRes.png)
Fact Sheet Type | Layer | Changes
---|---|---
[Platform](https://help.sap.com/docs/leanix/ea/platform-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model platforms. This includes best practices and applicable use cases, and common antipatterns.") | 1. Strategy & Transformation | New Fact Sheet type
[Objective](https://help.sap.com/docs/leanix/ea/objective-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model objectives. This includes best practices and applicable use cases, and common antipatterns.") | 1. Strategy & Transformation | No changes
[Initiative](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model initiatives. This includes best practices and applicable use cases, and common antipatterns.") | 1. Strategy & Transformation | Renamed from Project Added subtypes: Idea, Program, Project, Epic
[Business Capability](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page covers modeling guidelines for business capabilities. Learn about best practices and applicable use cases, and avoid common antipatterns.") | 2. Business Architecture | Maturity section with Maturity and Strategic Importance fields is now a default section in the Information section of the Fact Sheet type (previously available as a custom field)
[Organization](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model organizations. This includes best practices and applicable use cases, and common antipatterns.") | 2. Business Architecture | Renamed from User Group Added subtypes: Business Unit, Customer, Region, Legal Entity, Team
[Business Context](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model business contexts. This includes best practices and applicable use cases, and common antipatterns.") | 2. Business Architecture | Renamed from Process Added subtypes: Business Product, Customer Journey, Process, Value Stream, ESG Capability (optional feature)
[Application](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page guides you on modeling applications, covering subtypes, best practices, versioning, hierarchies, and use cases. Avoid common antipatterns and gain valuable insights.") | 3. Application & Data Architecture | Added subtypes: Business Application, Microservice (optional) Portfolio Strategy section with [Gartner® TIME Framework](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD) and [6R Framework](https://help.sap.com/docs/leanix/ea/6r?locale=en-US&state=PRODUCTION&version=CLOUD) Classification fields is now a default section in the Fact Sheet type (previously available as a custom field)
[Data Object](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model data objects. This includes best practices and applicable use cases, and common antipatterns.") | 3. Application & Data Architecture | No changes
[Interface](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model interfaces. This includes best practices and applicable use cases, and common antipatterns.") | 3. Application & Data Architecture | Added subtypes: Logical Interface, API
[Tech Category](https://help.sap.com/docs/leanix/ea/tech-category-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model tech categories. This includes best practices and applicable use cases, and common antipatterns.") | 4. Technical architecture | No changes
[IT Component](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model IT components. This includes best practices and applicable use cases, and common antipatterns.") | 4. Technical architecture | Added further subtypes: IaaS, PaaS, SaaS
[Provider](https://help.sap.com/docs/leanix/ea/provider-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model providers. This includes best practices and applicable use cases, and common antipatterns.") | 4. Technical architecture | No changes


